#L. Beauguitte, groupe fmr, février 2015

rm(list=ls())

library(igraph)
#import fichier

liens <- read.table("liens2.txt", header=TRUE, sep=";")
attributs <- read.table("attributs.txt", header=TRUE, sep=";")

g <- graph.data.frame(liens, vertices = attributs)

g

#représentation graphique

vertexSiz <- get.vertex.attribute(g, "ANC")
vertexCol <- get.vertex.attribute(g,"TEAM")
colors = c("Red","Blue")
vertexCol[vertexCol == "A"] = colors[1]
vertexCol[vertexCol == "B"] = colors[2]
edgeW <- get.edge.attribute(g, "I")

plot(g, vertex.size = vertexSiz, vertex.color = vertexCol,
     edge.width = edgeW*2, edge.curved=TRUE)

#filtrer sur les attributs des liens : liens < 2

g2 <- delete.edges(g,E(g)[I<2])
g2 
plot(g2)

#filtrer sur les sommets : degré < 2

g22 <- delete.vertices(g, V(g)[degree(g) < 2]) 
plot(g22)

#mesures globales

#densité
graph.density(g) #8/42

#composantes connexes
clusters(g) #appartenance ($membership), ordre ($csize) et nombre ($no) - par défaut, weak (orientation ne compte pas)
clusters(g, mode="strong")

diameter(g)

cliques(g) #taille 1, 2 etc : tout sommet non isolé est une clique d'ordre 1
#tout lien une clique d'ordre 2
#ignore la direction et pas d'option possible
cliques(g, min=3) #abc et bcd

dyad.census(g)
triad.census(g) #mêmes résultats que statnet mais sans rappel de la classification MAN

#mesures locales
#mesure du degré

degree(g) #par défaut, degré brut in + out
degree(g, mode = "in") #degré entrant
degree(g, mode="in", normalized = TRUE) #normalisation par degré maximal possible (6)

#distribution

degree.distribution(g) #proportion de sommets de degré in + out 0, 1, 2 etc. 
#ici max 3 donc liste de 4
plot(degree.distribution(g)) #attention à l'axe des abscisses qui commence à 1 au lieu de zéro...

#log -log. n'a pas grand sens ici, donné pour information

deg <- table(degree(g))
plot(names(deg), deg, log="xy")

#centralité de proximité (closeness)

closeness(g) #résultats absurdes car graphe non connexe et présence d'un isolé

#pour avoir résultat correct, décomposer selon composantes connexes

g2 <- decompose.graph(g)
plot(g2[[1]])
sapply(g2, closeness, mode="all") #à quoi correspond le résultat de d
#a         b         c         d 
#0.2500000 0.3333333 0.3333333 0.2500000 

#edge betweenness
edge.betweenness(g, directed=TRUE) #toujours supérieure ou égale à 1. 
#donné dans l'ordre des liens dans le fichier de départ
#quatrième lien ba = 2 et lien 6 db= 2
edge.betweenness(g, directed=FALSE) #trop de liens au départ don résultats non compréensibles
#[1] 0.5000000 0.5000000 0.8333333 0.8333333 1.3333333 1.6666667 1.3333333 1.0000000

#moyen de mesurer correctement l'intermédiarité des liens
g3 <- as.undirected(g)
edge.betweenness(g3)

#transitivité - considère que le graphe est non orienté quoi qu'il arrive
transitivity(g, "local") #NaN not a number - résultats cohérents
#[1] 0.3333333 0.3333333 0.6666667 1.0000000 0.0000000 0.0000000       NaN

#si on mesure sur le graphe non orienté généré plus haut, le résultat est cohérent
transitivity(g3, "local")

#plus courts chemins

shortest.paths(g) #par défaut, non orienté
shortest.paths(g, mode="out")

#degree de centralisation

#controle centralization

d <- rbind(c(0,1), c(0,2), c(0,3), c(0,4), c(0,5), c(0,6), c(0,7), c(0,8), c(0,9))
g <- graph.data.frame(d, directed=FALSE)
plot(g)
centralization.degree(g)
centralization.degree(g, normalized=TRUE)  #0.8 faux 

#valeur correcte pour les cercles
d1 <- rbind(c("a","b"),c("b","c"), c("c","d"), c("d","e"), c("e","a"))
g1 <- graph.data.frame(d1, directed=FALSE)
plot(g1)
centralization.degree(g1) #0

